@@ -21,34 +21,34 @@
 #endif
 #include "luv.h"
 
-#include "util.c"
-#include "lhandle.c"
-#include "lreq.c"
-#include "loop.c"
-#include "req.c"
-#include "handle.c"
-#include "timer.c"
-#include "prepare.c"
-#include "check.c"
-#include "idle.c"
 #include "async.c"
-#include "poll.c"
-#include "signal.c"
-#include "process.c"
-#include "stream.c"
-#include "tcp.c"
-#include "pipe.c"
-#include "tty.c"
-#include "udp.c"
+#include "check.c"
+#include "constants.c"
+#include "dns.c"
+#include "fs.c"
 #include "fs_event.c"
 #include "fs_poll.c"
-#include "fs.c"
-#include "dns.c"
-#include "thread.c"
-#include "work.c"
-#include "misc.c"
-#include "constants.c"
+#include "handle.c"
+#include "idle.c"
+#include "lhandle.c"
+#include "loop.c"
+#include "lreq.c"
 #include "metrics.c"
+#include "misc.c"
+#include "pipe.c"
+#include "poll.c"
+#include "prepare.c"
+#include "process.c"
+#include "req.c"
+#include "signal.c"
+#include "stream.c"
+#include "tcp.c"
+#include "thread.c"
+#include "timer.c"
+#include "tty.c"
+#include "udp.c"
+#include "util.c"
+#include "work.c"
 
 static const luaL_Reg luv_functions[] = {
   // loop.c
@@ -148,6 +148,9 @@ static const luaL_Reg luv_functions[] = {
   {"write", luv_write},
   {"write2", luv_write2},
   {"try_write", luv_try_write},
+#if LUV_UV_VERSION_GEQ(1, 42, 0)
+  {"try_write2", luv_try_write2},
+#endif
   {"is_readable", luv_is_readable},
   {"is_writable", luv_is_writable},
   {"stream_set_blocking", luv_stream_set_blocking},
@@ -447,6 +450,9 @@ static const luaL_Reg luv_stream_methods[] = {
   {"write", luv_write},
   {"write2", luv_write2},
   {"try_write", luv_try_write},
+#if LUV_UV_VERSION_GEQ(1, 42, 0)
+  {"try_write2", luv_try_write2},
+#endif
   {"is_readable", luv_is_readable},
   {"is_writable", luv_is_writable},
   {"set_blocking", luv_stream_set_blocking},
@@ -647,6 +653,7 @@ static void luv_req_init(lua_State* L) {
 LUALIB_API int luv_cfpcall(lua_State* L, int nargs, int nresult, int flags) {
   int ret, top, errfunc;
 
+  top  = lua_gettop(L);
   // Get the traceback function in case of error
   if ((flags & (LUVF_CALLBACK_NOTRACEBACK|LUVF_CALLBACK_NOERRMSG) ) == 0)
   {
@@ -657,7 +664,6 @@ LUALIB_API int luv_cfpcall(lua_State* L, int nargs, int nresult, int flags) {
     errfunc -= (nargs+1);
   }else
     errfunc = 0;
-  top  = lua_gettop(L);
 
   ret = lua_pcall(L, nargs, nresult, errfunc);
   switch (ret) {
@@ -694,6 +700,15 @@ LUALIB_API int luv_cfpcall(lua_State* L, int nargs, int nresult, int flags) {
   return ret;
 }
 
+// Call lua c function in protected mode. When error occurs, it will print
+// error message to stderr, and memory allocation error will cause exit.
+LUALIB_API int luv_cfcpcall(lua_State* L, lua_CFunction func, void * ud, int flags) {
+  lua_pushcfunction(L, func);
+  lua_pushlightuserdata(L, ud);
+  int ret = luv_cfpcall(L, 1, 0, flags);
+  return ret;
+}
+
 // TODO: see if we can avoid using a string key for this to increase performance
 static const char* luv_ctx_key = "luv_context";
 
@@ -735,7 +750,19 @@ LUALIB_API void luv_set_loop(lua_State* L, uv_loop_t* loop) {
 // Set an external event callback routine, before luaopen_luv
 LUALIB_API void luv_set_callback(lua_State* L, luv_CFpcall pcall) {
   luv_ctx_t* ctx = luv_context(L);
-  ctx->pcall = pcall;
+  ctx->cb_pcall = pcall;
+}
+
+// Set an external thread routine, before luaopen_luv
+LUALIB_API void luv_set_thread(lua_State* L, luv_CFpcall pcall) {
+  luv_ctx_t* ctx = luv_context(L);
+  ctx->thrd_pcall = pcall;
+}
+
+// Set an external c thread routine, before luaopen_luv
+LUALIB_API void luv_set_cthread(lua_State* L, luv_CFcpcall cpcall) {
+  luv_ctx_t* ctx = luv_context(L);
+  ctx->thrd_cpcall = cpcall;
 }
 
 static void walk_cb(uv_handle_t *handle, void *arg)
@@ -795,10 +822,25 @@ LUALIB_API int luaopen_luv (lua_State* L) {
     if (ret < 0) {
       return luaL_error(L, "%s: %s\n", uv_err_name(ret), uv_strerror(ret));
     }
+
+    /* do cleanup in main thread */
+    lua_getglobal(L, "_THREAD");
+    if (lua_isnil(L, -1))
+      atexit(luv_work_cleanup);
+    lua_pop(L, 1);
   }
   // pcall is NULL, luv use default callback routine
-  if (ctx->pcall==NULL) {
-    ctx->pcall = luv_cfpcall;
+  if (ctx->cb_pcall==NULL) {
+    ctx->cb_pcall = luv_cfpcall;
+  }
+
+  // pcall is NULL, luv use default thread routine
+  if (ctx->thrd_pcall==NULL) {
+    ctx->thrd_pcall = luv_cfpcall;
+  }
+
+  if (ctx->thrd_cpcall==NULL) {
+    ctx->thrd_cpcall = luv_cfcpcall;
   }
 
   luv_req_init(L);
